
package com.tmerclub.cloud.api.product.dto;

import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.NotBlank;
import lombok.Data;
import org.hibernate.validator.constraints.Length;

import java.io.Serial;
import java.io.Serializable;

/**
 * 品牌店铺关联信息DTO
 *
 * @author tmerclub
 * @date 2021-05-08 13:31:45
 */
@Data
public class BrandShopDTO implements Serializable {
    @Serial
    private static final long serialVersionUID = 1L;
    @Schema(description = "主键id")
    private Long brandShopId;

    @Schema(description = "店铺id")
    private Long shopId;

    @Schema(description = "品牌id")
    private Long brandId;

    @Schema(description = "授权资质图片，以,分割")
    @NotBlank(message = "授权资质图片不能为空")
    private String qualifications;

    @Schema(description = "类型 0：平台品牌，1：店铺自定义品牌")
    private Integer type;

    @Schema(description = "检索首字母")
    @Length(max = 1, message = "检索首字母长度不能超过1")
    private String firstLetter;

    @Schema(description = "排序")
    private Integer seq;

    @Schema(description = "是否置顶 0：不置顶  1：置顶")
    private Integer isTop;

    @Schema(description = "logo")
    private String imgUrl;

    @Schema(description = "品牌名称")
    private String name;

    @Schema(description = "品牌描述")
    private String desc;

    @Schema(description = "品牌状态")
    private Integer status;

    @Schema(description = "分类id")
    private Long categoryId;

    @Schema(description = "关联系统类型 1.店铺 2.平台端 3.供应商")
    private Integer sysType;


    @Override
    public String toString() {
        return "BrandShopDTO{" +
                "brandShopId=" + brandShopId +
                ", shopId=" + shopId +
                ", brandId=" + brandId +
                ", qualifications='" + qualifications + '\'' +
                ", type=" + type +
                ", firstLetter='" + firstLetter + '\'' +
                ", seq=" + seq +
                ", isTop=" + isTop +
                ", imgUrl='" + imgUrl + '\'' +
                ", name='" + name + '\'' +
                ", categoryId=" + categoryId +
                ", desc='" + desc + '\'' +
                ", status=" + status +
                ", sysType=" + sysType +
                ", status=" + status +
                '}';
    }
}
