
package com.tmerclub.cloud.flow.bo;

import com.tmerclub.cloud.common.model.BaseModel;
import lombok.Data;
import lombok.ToString;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;

import java.io.Serializable;


/**
 * 用户端记录
 *
 * @author YXF
 * @date 2020-07-13 13:18:33
 */
@CompoundIndexes({
            @CompoundIndex(name = "date_type_system_type_idx", def = "{'dateType':1, 'systemType':1}"),
        @CompoundIndex(name = "spu_user_idx", def = "{'spuId':1, 'userId':1}")
})
@Document("flow_system")
@Data
@ToString
public class FlowSystemBO extends BaseModel implements Serializable{

    public static final Integer ID_LENGTH = 8;

    /**
     * id: 日期（yyMMdd）+ 日期类型（日周月） + 系统类型
     * 长度：8位
     */
    @Id
    private Integer id;

    /**
     * 系统类型 0:全部 1:pc  2:h5  3:小程序 4:安卓  5:ios
     */
    private Integer systemType;

    /**
     * 日、周、月
     */
    private Integer dateType;

    /**
     * 浏览量
     */
    private Integer visit;

    /**
     * 加购人数
     */
    private Integer plusShopCartUser;

    /**
     * 访客数
     */
    private Integer visitUser;

    /**
     * 新访客数
     */
    private Integer newVisitUser;

    /**
     * 跳失人数
     */
    private Integer lossUser;

    /**
     * 下单人数
     */
    private Integer placeOrderUser;

    /**
     * 支付人数
     */
    private Integer payUser;

    /**
     * 下单金额
     */
    private Integer placeOrderAmount;

    /**
     * 支付金额
     */
    private Integer payAmount;


}
