
package com.tmerclub.cloud.flow.bo;

import com.tmerclub.cloud.common.model.BaseModel;
import lombok.Data;
import lombok.ToString;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;

import java.io.Serializable;


/**
 * 各平台端用户记录
 *
 * @author YXF
 * @date 2020-07-13 13:18:33
 */
@CompoundIndexes({
        @CompoundIndex(name = "user_idx", def = "{'userId':1}"),
        @CompoundIndex(name = "date_type_system_type_idx", def = "{'dateType':1, 'systemType':1}")
})
@Document("flow_system_user")
@Data
@ToString
public class FlowSystemUserBO extends BaseModel implements Serializable{

    public static final Integer ID_LENGTH = 18;


    /**
     * id: 日期（yyMMdd）+ 日期类型（日周月） + 系统类型 + 编号
     * 长度：18位
     */
    @Id
    private Long id;

    /**
     * 用户id
     */
    private Long userId;


    /**
     * 系统类型 0:全部 1:pc  2:h5  3:小程序 4:安卓  5:ios
     */
    private Integer systemType;

    /**
     * 日、周、月
     */
    private Integer dateType;

    /**
     * 是否加购 0: 否 1：是
     */
    private Integer plusShopCart;

    /**
     * 新访客  0: 否 1：是
     */
    private Integer newVisitUser;

    /**
     * 是否跳失  0: 否 1：是
     */
    private Integer loss;

    /**
     * 是否下单  0: 否 1：是
     */
    private Integer placeOrder;

    /**
     * 是否支付  0: 否 1：是
     */
    private Integer pay;


}
