
package com.tmerclub.cloud.product.service;

import com.tmerclub.cloud.common.database.dto.PageDTO;
import com.tmerclub.cloud.common.database.vo.PageVO;
import com.tmerclub.cloud.product.dto.TakeStockDTO;
import com.tmerclub.cloud.product.model.TakeStockSpu;
import com.tmerclub.cloud.product.vo.TakeStockSpuExcelVO;
import com.tmerclub.cloud.product.vo.TakeStockSpuImportVO;
import com.tmerclub.cloud.product.vo.TakeStockSpuVO;
import jakarta.servlet.http.HttpServletResponse;

import java.util.List;
import java.util.Set;

/**
 * 盘点商品列表
 *
 * @author lhd
 * @date 2022-06-22 16:57:27
 */
public interface TakeStockSpuService {

    /**
     * 分页获取盘点商品列表列表
     * @param pageDTO 分页参数
     * @return 盘点商品列表列表分页数据
     */
    PageVO<TakeStockSpu> page(PageDTO pageDTO);

    /**
     * 根据盘点商品列表id获取盘点商品列表
     *
     * @param takeStockSpuId 盘点商品列表id
     * @return 盘点商品列表
     */
    TakeStockSpu getByTakeStockSpuId(Long takeStockSpuId);

    /**
     * 保存盘点商品列表
     * @param takeStockSpu 盘点商品列表
     */
    void save(TakeStockSpu takeStockSpu);

    /**
     * 更新盘点商品列表
     * @param takeStockSpu 盘点商品列表
     */
    void update(TakeStockSpu takeStockSpu);

    /**
     * 根据盘点商品列表id删除盘点商品列表
     * @param takeStockSpuId 盘点商品列表id
     */
    void deleteById(Long takeStockSpuId);

    /**
     * 根据takeStockDTO更新实物盘点商品
     * @param takeStockDTO
     */
    void updateByTakeStockDTO(TakeStockDTO takeStockDTO);

    /**
     * 通过实物盘点id获取实物盘点商品信息
     * @param takeStockId
     * @return
     */
    List<TakeStockSpuVO> listByTakeStockId(Long takeStockId);

    /**
     * 下载实物盘点商品excel导入模板
     * @param response
     */
    void downloadModel(HttpServletResponse response);

    /**
     * 导入实物盘点商品excel
     *
     * @param list
     * @param errorList
     * @param partyCodes
     * @param takeStockId
     * @param takeStockSpuImportVO
     */
    void importExcel(List<TakeStockSpuExcelVO> list, List<String> errorList, Set<String> partyCodes, Long takeStockId, TakeStockSpuImportVO takeStockSpuImportVO);

    /**
     * 导出实物盘点商品excel
     * @param takeStockId
     * @param response
     */
    void exportExcel(Long takeStockId, HttpServletResponse response);
}
